@@ -16,9 +16,7 @@
 #include "globals.h" /* defines and declarations for database filenames */
 
 #include <stdio.h>
-#include <malloc.h>
 #include <ctype.h>
-#include "emalloc.h"
 #include <sys/types.h>
 
 #ifdef HAVE_FCNTL_H
@@ -36,6 +34,8 @@
 
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
+#else
+# include <malloc.h>
 #endif
 
 #ifdef HAVE_UNISTD
@@ -93,7 +93,7 @@ LQTp_PrintOneTraceFlag(Name, Value, isSet)
     int isSet;
 {
     fprintf(stderr,
-	"\t%-08o  %s%s\n",
+	"\t%08o  %s%s\n",
 	Value,
 	Name,
 	isSet ? " (this flag is set)" : ""
