@@ -6,7 +6,7 @@
  * lqkwic -- produce a keyword-in-context list of matches...
  * Liam R. Quin, February 1991 and later...
  *
- * $Id: lqkwic.c,v 1.41 2000/03/01 05:13:20 lee Exp lee $
+ * $Id: lqkwic.c,v 1.43 2001/05/31 03:50:13 liam Exp $
  *
  *
  * lqkwic presents user with a keyword-in-context (KWIC) index,
@@ -43,7 +43,6 @@
 #endif
 
 
-#include <malloc.h>
 #include <ctype.h>
 #ifdef HAVE_STRING_H
 # include <string.h>
@@ -51,6 +50,13 @@
 # include <strings.h>
 #endif
 
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#else
+# include <malloc.h>
+#endif
+
+
 #include "range.h"
 #include "fileinfo.h"
 #include "wordinfo.h"
@@ -172,7 +178,7 @@ PRIVATE void OutputMatch(
 
 char *progname = "lqkwic"; /* set from argv[] in main() */
 
-static char *Revision = "@(#) $Id: lqkwic.c,v 1.41 2000/03/01 05:13:20 lee Exp lee $";
+static char *Revision = "@(#) $Id: lqkwic.c,v 1.43 2001/05/31 03:50:13 liam Exp $";
 
 PRIVATE int TruncateAtPath = 0;
 PRIVATE int MatchesHaveWordCount = 1;
@@ -189,6 +195,8 @@ PRIVATE int LeftWidth = DEFAULT_SCREENWIDTH * 2;
 PRIVATE int RightWidth = DEFAULT_SCREENWIDTH * 2;
 PRIVATE int GapWidth = 0;
 
+PRIVATE int unbufferedMode = 0;
+
 PRIVATE unsigned long LineNumber = 0L;
 PRIVATE char *theMatchFileFormat =
 	"==== Document ${FileNumber}: ${FileName} ====${NEWLINE}";
@@ -267,7 +275,7 @@ main(argc, argv)
     /* All lq-text programs must call LQT_InitFromArgv() before getopt, and
      * must then be prepared to ignore options z with arg and Z without.
      */
-    while ((ch = getopt(argc, argv, "A:C:ceE:f:g:i:Ll:Mo:O:p:r:S:s:Vvxz:Z")) != EOF) {
+    while ((ch = getopt(argc, argv, "A:C:ceE:f:g:i:Ll:Mo:O:p:r:S:s:uVvxz:Z")) != EOF) {
 	switch (ch) {
 	case 'Z':
 	case 'z':
@@ -337,6 +345,9 @@ main(argc, argv)
 	case 's':
 	    theMatchFormat = optarg;
 	    break;
+	case 'u':
+	    unbufferedMode= 1;
+	    break;
 	case 'v':
 	    if (LQT_SetTraceFlag(LQTRACE_VERBOSE)) {
 		/* it was already set */
@@ -407,7 +418,8 @@ main(argc, argv)
 	    fprintf(stderr, "\
 	-s fmt	-- use the given format to display each match\n\
 	-S fmt  -- use the given format to display each file name\n\
-		   (-v -L lists available variables and default values)\n"
+		   (-v -L lists available variables and default values)\n
+	-u    	--unbuffered mode; flush output after each result\n"
 	    );
 	}
 
@@ -1329,6 +1341,9 @@ ShowOneMatch(
 	);
     }
 
+    if (unbufferedMode) {
+	(void) fflush(stdout);
+    }
     return 0;
 }
 
